@@ -1,19 +1,10 @@
-//! Pure Rust implementation of [SEC1: Elliptic Curve Cryptography] encoding
-//! formats including ASN.1 DER-serialized private keys (also described in
-//! [RFC5915]) as well as the `Elliptic-Curve-Point-to-Octet-String` and
-//! `Octet-String-to-Elliptic-Curve-Point` encoding algorithms.
-//!
-//! # Minimum Supported Rust Version
-//! This crate requires **Rust 1.51** at a minimum.
-//!
-//! [SEC1: Elliptic Curve Cryptography]: https://www.secg.org/sec1-v2.pdf
-//! [RFC5915]: https://datatracker.ietf.org/doc/html/rfc5915
 #![no_std]
 #![cfg_attr(docsrs, feature(doc_cfg))]
+#![doc = include_str!("../README.md")]
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/sec1/0.1.0"
+    html_root_url = "https://docs.rs/sec1/0.2.0"
 )]
 #![forbid(unsafe_code, clippy::unwrap_used)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
@@ -37,17 +28,27 @@ pub use self::{
     parameters::EcParameters,
     point::EncodedPoint,
     private_key::EcPrivateKey,
-    traits::FromEcPrivateKey,
+    traits::DecodeEcPrivateKey,
 };
 
 pub use generic_array::typenum::consts;
 
+#[cfg(feature = "alloc")]
+pub use crate::{private_key::document::EcPrivateKeyDocument, traits::EncodeEcPrivateKey};
+
 #[cfg(feature = "pem")]
 #[cfg_attr(docsrs, doc(cfg(feature = "pem")))]
-pub use pem_rfc7468::LineEnding;
+pub use der::pem::{self, LineEnding};
 
-#[cfg(feature = "alloc")]
-pub use crate::{private_key::document::EcPrivateKeyDocument, traits::ToEcPrivateKey};
+#[cfg(feature = "pkcs8")]
+#[cfg_attr(docsrs, doc(cfg(feature = "pkcs8")))]
+pub use pkcs8;
 
-#[cfg(feature = "pem")]
-use pem_rfc7468 as pem;
+/// Algorithm [`ObjectIdentifier`] for elliptic curve public key cryptography
+/// (`id-ecPublicKey`).
+///
+/// <http://oid-info.com/get/1.2.840.10045.2.1>
+#[cfg(feature = "pkcs8")]
+#[cfg_attr(docsrs, doc(cfg(feature = "pkcs8")))]
+pub const ALGORITHM_OID: pkcs8::ObjectIdentifier =
+    pkcs8::ObjectIdentifier::new("1.2.840.10045.2.1");
